@@ -117,7 +117,7 @@ def mv(source, dest, overwrite=True):  # pylint: disable=invalid-name
         raise TypeError("source is not file or dir")
 
 
-def rm(path):  # pylint: disable=invalid-name
+def rm(path, recursive=False):  # pylint: disable=invalid-name
     """
     Remove path or (empty) directory
     """
@@ -125,9 +125,12 @@ def rm(path):  # pylint: disable=invalid-name
     if os.path.isfile(path):
         os.remove(path)
     elif os.path.isdir(path):
-        if len(ls(path)) > 0:
-            raise ValueError("Directory {0} is not empty".format(path))
-        os.rmdir(path)
+        if recursive:
+            shutil.rmtree(path)
+        else:
+            if len(ls(path)) > 0:
+                raise ValueError("Directory {0} is not empty".format(path))
+            os.rmdir(path)
     else:
         raise ValueError("Path {0} is not directory and not file".format(path))
 
@@ -190,8 +193,17 @@ def tree(directory):
     """
     Creates a nested dictionary that represents the folder structure of
     directory
+
+    Examples:
+        >>> import rna
+        >>> import pathlib
+        >>> this = pathlib.Path(__file__)
+        >>> directory = this.parent
+        >>> this.name in rna.path.tree(directory)
+        True
     """
     dir_structure = {}
+    directory = resolve(directory)
     directory = directory.rstrip(os.sep)
     start = directory.rfind(os.sep) + 1
     for path, dirs, files in os.walk(directory):  # pylint: disable=unused-variable
@@ -201,4 +213,6 @@ def tree(directory):
         parent[folders[-1]] = subdir
     if len(dir_structure) == 0:
         return {}
-    return dir_structure[dir_structure.keys()[0]]  # first entry is always directory
+    return dir_structure[
+        list(dir_structure.keys())[0]
+    ]  # first entry is always directory
